@@ -42,6 +42,8 @@ def _format_item(k, v):
 def match_value(value, pattern):
     if isinstance(value, (list, tuple)):
         return any(match_value(v, pattern) for v in value)
+    if isinstance(pattern, (list, tuple)):
+        return any(match_value(value, p) for p in pattern)
     if isinstance(value, str) and isinstance(pattern, str):
         return fnmatch.fnmatch(value.lower(), pattern.lower())
     return lower(value) == lower(pattern)
@@ -59,6 +61,8 @@ class DeviceFilter:
         'is_filesystem',
         'is_luks',
         'is_loop',
+        # FIXME: experimental/undocumented
+        'is_loopfile',
         'is_toplevel',
         'is_detachable',
         'is_ejectable',
@@ -83,6 +87,7 @@ class DeviceFilter:
         'in_use',
         'should_automount',
         'ui_label',
+        'ui_label_dialog',
         'loop_file',
         'setup_by_uid',
         'autoclear',
@@ -233,8 +238,11 @@ class Config:
         # False/'' => no config
         if not path:
             return cls({})
-        if os.path.splitext(path)[1].lower() == '.json':
+        ext = os.path.splitext(path)[1].lower()
+        if ext == '.json':
             from json import load
+        elif ext == '.toml':
+            from tomllib import load
         else:
             from yaml import safe_load as load
         with open(path) as f:
